/**************************************
 Send various packets to to the server
 (c) 1999 Jeremy Wise
 GnomeICU
***************************************/

#ifndef __RESPONSE_H__
#define __RESPONSE_H__

#include "common.h"
#include "filexfer.h"
#include "v7base.h"

void User_Online( GSList *contact );
void User_Offline( GSList *contact );
void Shortcut_Update( CONTACT_PTR contact );
void Shortcut_Update_All( void );
void Do_File( char *msg, UIN_T uin, gchar *msgid, gchar *file_name,
		   int file_size, V7Connection *conn);
void msg_received (UIN_T uin, gchar *msg, time_t msg_time);
void url_received (UIN_T uin, const gchar *url, const gchar *desc, time_t msg_time);
void contact_list_received (UIN_T uin, GSList *contacts, time_t msg_time);
void user_added_you (UIN_T uin, time_t msg_time);
void authorization_request(UIN_T uin, gchar *nick, gchar *first, gchar *last,
                           gchar *email, gchar *msg, time_t msg_time);
void recv_awaymsg( UIN_T uin, DWORD status, const gchar *message);
void start_transfer( UIN_T uin, gchar *msgid, DWORD fileip, WORD fileport);
void set_contact_status (GSList *contact, int status);

#endif /* __RESPONSE_H__ */
